@@ -1,6 +1,7 @@
 from minio import Minio
 import os
 import io
+import base64
 
 class PyMinio:
     def __init__(self, host, port, access_key, secret_key, secure=False):
@@ -72,3 +73,40 @@ class PyMinio:
 
     def get_client(self) -> Minio:
         return self.client
+
+    def upload_image(self, image_base64:str, *, object_name=None, filetype=None, bucket=None):
+        partition = image_base64.find(",")
+        if partition > 0:
+            image_base64 = image_base64[partition:]
+        else:
+            image_base64 = image_base64
+        image_data = base64.b64decode(image_base64)
+
+        if object_name!=None and object_name[0]=='/':
+            object_name = object_name[1:]
+
+        if bucket==None:
+            bucket = self.bucket
+
+        #
+        if object_name==None:
+            if filetype==None:
+                import imghdr
+
+                # 通过二进制内容获取图片格式
+                filetype = imghdr.what(None, image_data)
+                if filetype==None:
+                    filetype = "unknown"
+
+            hash_md5 = hashlib.md5()
+            hash_md5.update(image_data)
+            image_name = hash_md5.hexdigest() + "." + filetype
+            object_name = "{}/{}.{}".format(image_name[:2], image_name[2:], filetype)
+
+        result = self.client.put_object(bucket, object_name, image_data, len(image_data))
+
+        if result!=None:
+            return "{}/{}".format(bucket, object_name)
+        else:
+            return None
+        
